aboutsummaryrefslogtreecommitdiffstats
path: root/test/monniaux/bitsliced-tea/reduce/compare.sh
diff options
context:
space:
mode:
Diffstat (limited to 'test/monniaux/bitsliced-tea/reduce/compare.sh')
-rwxr-xr-xtest/monniaux/bitsliced-tea/reduce/compare.sh18
1 files changed, 9 insertions, 9 deletions
diff --git a/test/monniaux/bitsliced-tea/reduce/compare.sh b/test/monniaux/bitsliced-tea/reduce/compare.sh
index f0b1f8d2..7f96491b 100755
--- a/test/monniaux/bitsliced-tea/reduce/compare.sh
+++ b/test/monniaux/bitsliced-tea/reduce/compare.sh
@@ -5,16 +5,16 @@ GCC_K1="k1-cos-gcc -Werror=implicit -O3 $INCLUDES"
GCC_HOST="gcc -Werror=implicit -O3 $INCLUDES"
FILE=bstea.c
-OTHERS_K1="$PREFIX/test/monniaux/bitsliced-tea/bstea_run.gcc.k1c.o $PREFIX/test/monniaux/clock.gcc.k1c.o"
+OTHERS_K1="$PREFIX/test/monniaux/bitsliced-tea/bstea_run.gcc.kvx.o $PREFIX/test/monniaux/clock.gcc.kvx.o"
OTHERS_HOST="$PREFIX/test/monniaux/bitsliced-tea/bstea_run.gcc.host.o $PREFIX/test/monniaux/clock.gcc.host.o"
-$CCOMP_K1 $FILE $OTHERS_K1 -o bstead.ccomp.k1c &&
-$GCC_K1 $FILE $OTHERS_K1 -o bstead.gcc.k1c &&
+$CCOMP_K1 $FILE $OTHERS_K1 -o bstead.ccomp.kvx &&
+$GCC_K1 $FILE $OTHERS_K1 -o bstead.gcc.kvx &&
$GCC_HOST $FILE $OTHERS_HOST -o bstead.gcc.host &&
valgrind -q ./bstead.gcc.host &&
-k1-cluster --cycle-based -- bstead.ccomp.k1c > bstead.ccomp.k1c.out &&
-k1-cluster --cycle-based -- bstead.gcc.k1c > bstead.gcc.k1c.out &&
-grep cycles bstead.ccomp.k1c.out|sed -e 's/cycles: //' > bstead.ccomp.k1c.cycles &&
-grep cycles bstead.gcc.k1c.out|sed -e 's/cycles: //' > bstead.gcc.k1c.cycles &&
-test `cat bstead.gcc.k1c.cycles` -gt 100000 &&
-test `cat bstead.ccomp.k1c.cycles` -gt 200000
+k1-cluster --cycle-based -- bstead.ccomp.kvx > bstead.ccomp.kvx.out &&
+k1-cluster --cycle-based -- bstead.gcc.kvx > bstead.gcc.kvx.out &&
+grep cycles bstead.ccomp.kvx.out|sed -e 's/cycles: //' > bstead.ccomp.kvx.cycles &&
+grep cycles bstead.gcc.kvx.out|sed -e 's/cycles: //' > bstead.gcc.kvx.cycles &&
+test `cat bstead.gcc.kvx.cycles` -gt 100000 &&
+test `cat bstead.ccomp.kvx.cycles` -gt 200000